@@ -14,16 +14,16 @@ const DW_FORCE_ATTACK: usize = 0x31EFCB4;
 
 fn hack_main_thread() {
     // Gets module handle
-    let module_handle: HMODULE = get_module_handle("client.dll");
+    let module_handle: HMODULE = get_module_handle("client.dll").unwrap();
     println!("module handle = {:?}", module_handle as usize);
 
     unsafe {
         // Gets function address
-        let function_address = get_module_function_address("USER32.dll", "MessageBoxA");
+        let function_address = get_module_function_address("USER32.dll", "MessageBoxA").unwrap();
         println!("function address = {:?}", function_address);
     }
 
-    let memory = Module::from_module_name("client.dll");
+    let memory = Module::from_module_name("client.dll").unwrap();
 
     let shoot_flag = cast!(mut module_handle as usize + DW_FORCE_ATTACK, u8);
     loop {
